@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.PinpointSMSVoiceV2 1.23.0\nVersion:        "
-        " 1.23.0.post1\nBuilder version: 7.5.14\nDocs:           "
+        "Type annotations for boto3.PinpointSMSVoiceV2 1.24.0\nVersion:         1.24.0\nBuilder"
+        " version: 7.6.1\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_pinpoint_sms_voice_v2//\nBoto3"
         " docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/pinpoint-sms-voice-v2.html#PinpointSMSVoiceV2\nOther"
@@ -23,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.23.0.post1")
+    print("1.24.0")
 
 
 def main() -> None:
