@@ -161,11 +161,7 @@ class PinpointSMSVoiceV2Client(BaseClient):
         """
 
     def create_configuration_set(
-        self,
-        *,
-        ConfigurationSetName: str,
-        Tags: Sequence["TagTypeDef"] = ...,
-        ClientToken: str = ...
+        self, *, ConfigurationSetName: str, Tags: Sequence[TagTypeDef] = ..., ClientToken: str = ...
     ) -> CreateConfigurationSetResultTypeDef:
         """
         Creates a new configuration set.
@@ -180,9 +176,9 @@ class PinpointSMSVoiceV2Client(BaseClient):
         ConfigurationSetName: str,
         EventDestinationName: str,
         MatchingEventTypes: Sequence[EventTypeType],
-        CloudWatchLogsDestination: "CloudWatchLogsDestinationTypeDef" = ...,
-        KinesisFirehoseDestination: "KinesisFirehoseDestinationTypeDef" = ...,
-        SnsDestination: "SnsDestinationTypeDef" = ...,
+        CloudWatchLogsDestination: CloudWatchLogsDestinationTypeDef = ...,
+        KinesisFirehoseDestination: KinesisFirehoseDestinationTypeDef = ...,
+        SnsDestination: SnsDestinationTypeDef = ...,
         ClientToken: str = ...
     ) -> CreateEventDestinationResultTypeDef:
         """
@@ -193,7 +189,7 @@ class PinpointSMSVoiceV2Client(BaseClient):
         """
 
     def create_opt_out_list(
-        self, *, OptOutListName: str, Tags: Sequence["TagTypeDef"] = ..., ClientToken: str = ...
+        self, *, OptOutListName: str, Tags: Sequence[TagTypeDef] = ..., ClientToken: str = ...
     ) -> CreateOptOutListResultTypeDef:
         """
         Creates a new opt-out list.
@@ -209,7 +205,7 @@ class PinpointSMSVoiceV2Client(BaseClient):
         IsoCountryCode: str,
         MessageType: MessageTypeType,
         DeletionProtectionEnabled: bool = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         ClientToken: str = ...
     ) -> CreatePoolResultTypeDef:
         """
@@ -344,7 +340,7 @@ class PinpointSMSVoiceV2Client(BaseClient):
         self,
         *,
         ConfigurationSetNames: Sequence[str] = ...,
-        Filters: Sequence["ConfigurationSetFilterTypeDef"] = ...,
+        Filters: Sequence[ConfigurationSetFilterTypeDef] = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> DescribeConfigurationSetsResultTypeDef:
@@ -360,7 +356,7 @@ class PinpointSMSVoiceV2Client(BaseClient):
         *,
         OriginationIdentity: str,
         Keywords: Sequence[str] = ...,
-        Filters: Sequence["KeywordFilterTypeDef"] = ...,
+        Filters: Sequence[KeywordFilterTypeDef] = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> DescribeKeywordsResultTypeDef:
@@ -387,7 +383,7 @@ class PinpointSMSVoiceV2Client(BaseClient):
         *,
         OptOutListName: str,
         OptedOutNumbers: Sequence[str] = ...,
-        Filters: Sequence["OptedOutFilterTypeDef"] = ...,
+        Filters: Sequence[OptedOutFilterTypeDef] = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> DescribeOptedOutNumbersResultTypeDef:
@@ -403,7 +399,7 @@ class PinpointSMSVoiceV2Client(BaseClient):
         self,
         *,
         PhoneNumberIds: Sequence[str] = ...,
-        Filters: Sequence["PhoneNumberFilterTypeDef"] = ...,
+        Filters: Sequence[PhoneNumberFilterTypeDef] = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> DescribePhoneNumbersResultTypeDef:
@@ -419,7 +415,7 @@ class PinpointSMSVoiceV2Client(BaseClient):
         self,
         *,
         PoolIds: Sequence[str] = ...,
-        Filters: Sequence["PoolFilterTypeDef"] = ...,
+        Filters: Sequence[PoolFilterTypeDef] = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> DescribePoolsResultTypeDef:
@@ -434,8 +430,8 @@ class PinpointSMSVoiceV2Client(BaseClient):
     def describe_sender_ids(
         self,
         *,
-        SenderIds: Sequence["SenderIdAndCountryTypeDef"] = ...,
-        Filters: Sequence["SenderIdFilterTypeDef"] = ...,
+        SenderIds: Sequence[SenderIdAndCountryTypeDef] = ...,
+        Filters: Sequence[SenderIdFilterTypeDef] = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> DescribeSenderIdsResultTypeDef:
@@ -486,7 +482,7 @@ class PinpointSMSVoiceV2Client(BaseClient):
         self,
         *,
         PoolId: str,
-        Filters: Sequence["PoolOriginationIdentitiesFilterTypeDef"] = ...,
+        Filters: Sequence[PoolOriginationIdentitiesFilterTypeDef] = ...,
         NextToken: str = ...,
         MaxResults: int = ...
     ) -> ListPoolOriginationIdentitiesResultTypeDef:
@@ -550,7 +546,7 @@ class PinpointSMSVoiceV2Client(BaseClient):
         PoolId: str = ...,
         RegistrationId: str = ...,
         DeletionProtectionEnabled: bool = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         ClientToken: str = ...
     ) -> RequestPhoneNumberResultTypeDef:
         """
@@ -643,7 +639,7 @@ class PinpointSMSVoiceV2Client(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_pinpoint_sms_voice_v2/client/#set_voice_message_spend_limit_override)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceArn: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Adds or overwrites only the specified tags for the specified Amazon Pinpoint SMS
         Voice, version 2 resource.
@@ -668,9 +664,9 @@ class PinpointSMSVoiceV2Client(BaseClient):
         EventDestinationName: str,
         Enabled: bool = ...,
         MatchingEventTypes: Sequence[EventTypeType] = ...,
-        CloudWatchLogsDestination: "CloudWatchLogsDestinationTypeDef" = ...,
-        KinesisFirehoseDestination: "KinesisFirehoseDestinationTypeDef" = ...,
-        SnsDestination: "SnsDestinationTypeDef" = ...
+        CloudWatchLogsDestination: CloudWatchLogsDestinationTypeDef = ...,
+        KinesisFirehoseDestination: KinesisFirehoseDestinationTypeDef = ...,
+        SnsDestination: SnsDestinationTypeDef = ...
     ) -> UpdateEventDestinationResultTypeDef:
         """
         Updates an existing event destination in a configuration set.
